@@ -42,7 +42,7 @@ def get_s3fs(
 
     verify = _to_bool(os.environ.get('S3_VERIFY', None)) if verify is None else verify
 
-    filesystem = S3FileSystem(client_kwargs={endpoint_url: endpoint_url, verify: verify})
+    filesystem = S3FileSystem(client_kwargs={'endpoint_url': endpoint_url, 'verify': verify})
 
     return filesystem
 
@@ -241,7 +241,7 @@ def save_npy(path: str, data: np.ndarray) -> None:
         np.save(path, data)
 
     else:
-        with io.open(path, mode='wb') as writer:
+        with open(path, mode='wb') as writer:
             np.save(writer, data)
 
 
